% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
%                4.3.2011      T. Roeder, Rohde&Schwarz
%
% *************************************************************************

% VISA instrument resource descriptor
% RscID   = 'TCPIP::rssmu200a101485::INSTR';
% RscID   = 'TCPIP::192.168.0.100::INSTR'; 
  RscID   = 'GPIB0::20::INSTR';  

% use VISA interface from National Instruments
  [status, InstrObject] = rs_connect( 'visa', 'ni', RscID );

disp( ' ' );
disp( '=== MEASURE POWER USING NRP BASE UNIT ===' );
disp( ' ' );

if( status<1 )
    disp (['*** Return status from rs_connect() is : ' num2str(status)]);
    return;
end

% read all errors from queue
rs_check_instrument_errors( InstrObject );

% Check if this is the NRP base unit.
%   Read the *IDN string and check for the word NRP.
[status, Result] = rs_send_query( InstrObject, '*IDN?' );
if( isempty( strfind( Result, 'NRP' ) ) )
    disp( 'Instrument type not supported' );
    delete( InstrObject ); return;
end

% Find out if a sensor is connected to port A of the base unit.
%   Get the Device Status Register content.
%   Bit 1 is set if a sensor is connected to port A
[status, Result] = rs_send_query( InstrObject, 'STAT:DEV:COND?' );
if( status<1 ); delete( InstrObject ); return; end;
BitVal = str2num( Result );
if( bitand( BitVal, 2 ) == 0 )
    disp( 'Please connect a sensor to port A.' );
    delete( InstrObject ); 
    return; 
end;
if( bitand( BitVal, 8 ) ~= 0 )
    disp( 'Sensor at port A is errornous.' );
    delete( InstrObject ); 
    return; 
end;

% get sensor type, e.g. NRP-Z11
[status, Result] = rs_send_query( InstrObject, 'SYST:SENS1:INFO? "TYPE"' );
if( status<1 ); delete( InstrObject ); return; end; 
disp( [ 'Sensor type at port A: ' strtrim(Result) ] );

% get serial number
[status, Result] = rs_send_query( InstrObject, 'SYST:SENS1:INFO? "SERIAL"' );
if( status<1 ); delete( InstrObject ); return; end; 
disp( [ 'Sensor serial number : ' strtrim(Result) ] );

disp( '  ' )

% run self test
% [status, Result] = rs_send_query( InstrObject, '*TST?' );
% if( status<0 || Result(1)~='0' ); 
%    disp('Self Test Failed'); 
%    delete( InstrObject ); 
%    return; 
% end

% reset instrument
[status, Result] = rs_send_query( InstrObject, '*RST; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% set measurement mode to continuous average power
[status, Result] = rs_send_query( InstrObject, 'SENS:FUNC "POW:AVG"; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% averaging on
[status, Result] = rs_send_query( InstrObject, 'SENS:AVER:STAT ON; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% no automatic filter mode
[status, Result] = rs_send_query( InstrObject, 'SENS:AVER:COUN:AUTO OFF; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% averaging filter count
[status, Result] = rs_send_query( InstrObject, 'SENS:AVER:COUN 64; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% get result in dBm
[status, Result] = rs_send_query( InstrObject, 'UNIT:POW DBM; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% frequency
[status, Result] = rs_send_query( InstrObject, 'SENS:FREQ 1 GHZ; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% level correction
[status, Result] = rs_send_query( InstrObject, 'SENS:CORR:OFFS:STAT ON; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end
[status, Result] = rs_send_query( InstrObject, 'SENS:CORR:OFFS 0 DB; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% check for errors
status = rs_check_instrument_errors( InstrObject );
if( status<0 ); delete( InstrObject ); return; end

% Run a few measurements
for Step = 1:1:10
    
    % start measurement
    [status] = rs_send_command( InstrObject, 'INIT' );
    if( status<0 ); delete( InstrObject ); return; end

    % get result
    [status, Result] = rs_send_query( InstrObject, 'READ?' );
    if( status<0 ); delete( InstrObject ); return; end

    % display result
    Power = str2double( Result );
    disp( [ 'Result = ' num2str( Power, '%5.1f' ) ' dBm' ] );

end

% clear variables
clear;

disp( '  ' );

return;


