% function rs_nrpz_setup_trace
% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
% *************************************************************************
% This function sets up a Trace measurement.
% @param  libname                     The name of the library.
% @param  session                     The session ID.
% @param  frequency                   The RF frequency in Hz.
% @param  leveloffset                 The level offset.
% @param  tracetime                   Trace time.
%%
% @return Status                      Status = 0, error occured.
%                                     Status = 1, OK.
%**************************************************************************
function [Status] = rs_nrpz_setup_trace( libname, session, frequency,...
                                          leveloffset, tracetime )  

    Status = 0;

    % we run the following commands in a dummy loop that allows for
    % an easier error handling
    while( true )

        % The sensor opened through rsnrpz_init() always uses channel 1.
        channel = 1;
        
        TracePoints = 500;

        % Configure the sensor for the trace measurement. This command sets the
        % sensor to the desired operating mode and all parameters to default
        % values.
        % 4 = RSNRPZ_SENSOR_MODE_SCOPE
        err = calllib( libname, 'rsnrpz_chan_mode', session, channel, 4 );
        if ( err );  break;  end;
    
        % Set the carrier frequency. This should always be done to obtain
        % correct readings.
        % 1e9 = 1 GHz
        err = calllib( libname, 'rsnrpz_chan_setCorrectionFrequency', ...
                            session, channel, frequency );
        if ( err );  break;  end;

        % Set an optional level offset that accounts for losses or coupling
        % factors.
        err = calllib( libname, 'rsnrpz_corr_setOffset', session, channel, leveloffset );
        if ( err );  break;  end;

        % Enable or disable using the level offset. The option must be enabled
        % if a level offset was set above.
        % 0 = disable
        err = calllib( libname, 'rsnrpz_corr_setOffsetEnabled', session, channel, 1 );
        if ( err );  break;  end;

        % Set to the full bandwidth. This is the default. The funtion is
        % provided only for completeness.
        err = calllib( libname, 'rsnrpz_bandwidth_setBw', session, channel, 0 );
        if ( err );  break;  end;

        % Set to 500 points trace length (video points). The number of trace
        % points must be set because buffers need to provide the correct
        % length.
        err = calllib( libname, 'rsnrpz_scope_setPoints', session, channel, TracePoints );
        if ( err );  break;  end;

        % Set total trace time to 10 ms.
        err = calllib( libname, 'rsnrpz_scope_setTime', session, channel, tracetime );
        if ( err );  break;  end;

        % Set trace offset to zero. The trigger point is located at video
        % point #0. See the NRP-Z Power Sensor manual for details about valid
        % ranges. This parameter has no effect in this example because we use
        % un untriggered measurement.
        err = calllib( libname, 'rsnrpz_scope_setOffsetTime', session, channel, 0 );
        if ( err );  break;  end;

        % Set to repeating filter mode. This parameter has no real effect in
        % this example because we do not use averaging.
        % 1 = RSNRPZ_TERMINAL_CONTROL_REPEAT
        err = calllib( libname, 'rsnrpz_avg_setTerminalControl', session, channel, 1 );
        if ( err );  break;  end;

        % Do not use aux. channels. We only read the average trace. Aux.
        % channels could be used to read peak, min. and random sampling trace
        % data as well (for sensors that support this feature).
        err = calllib( libname, 'rsnrpz_chan_setAuxiliary', session, channel, 0 );
        if ( err );  break;  end;

        % Configure the trigger system to immediate trigger. We do not wait for
        % any events. Usually this does not make sense for real measurements
        % but it ensures that this example always returns trace data evem if no
        % signal is present.
        % 3 = RSNRPZ_TRIGGER_SOURCE_IMMEDIATE
        err = calllib( libname, 'rsnrpz_trigger_setSource', session, channel, 3 );
        if ( err );  break;  end;

        % The average filter count is set to 1 and the filter turned off.
        % Averaging would not work with the immediate trigger.
        err = calllib( libname, 'rsnrpz_scope_setAverageCount', session, channel, 1 );
        if ( err );  break;  end;
        err = calllib( libname, 'rsnrpz_scope_setAverageEnabled', session, channel, 0 );
        if ( err );  break;  end;

        break;

    end

    % evaluate error
    if( err<0 )
        [dummy, ErrorText] = rs_nrpz_get_error( libname, session, err );
        disp( ErrorText );
        return;  
    end;
    
    Status = 1;

return;



